# Quickstart

- If you want to just call LLM APIs
  - Read [preparation](quickstart-preparation.md) and [`models`](quickstart-models.md).
    - For caching feature, you should read [`cache`](quickstart-core.md).
    - For function calling & tooling, you should read [`tool`](quickstart-agents.md#tool-function-calling).
- If you want to build an agent which perform complex conversation.
  - Also read [`agents`](quickstart-agents.md).

```{toctree}
quickstart-preparation.md
quickstart-models.md
quickstart-agents.md
quickstart-core.md
```
